==> flink-runtime_2.11-1.10.0-sources.jar: org/apache/flink/runtime/executiongraph/restart/ThrowingRestartStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flink.runtime.executiongraph.restart;

import org.apache.flink.runtime.concurrent.ScheduledExecutor;

import java.util.concurrent.CompletableFuture;


/**
 * A restart strategy that validates that it is not in use by throwing {@link IllegalStateException}
 * on any method call.
 */
public class ThrowingRestartStrategy implements RestartStrategy {

	@Override
	public boolean canRestart() {
		throw new IllegalStateException("Unexpected canRestart() call");
	}

	@Override
	public CompletableFuture<Void> restart(final RestartCallback restarter, final ScheduledExecutor executor) {
		throw new IllegalStateException("Unexpected restart() call");
	}

	/**
	 * Factory for {@link ThrowingRestartStrategy}.
	 */
	public static class ThrowingRestartStrategyFactory extends RestartStrategyFactory {

		private static final long serialVersionUID = 1L;

		@Override
		public RestartStrategy createRestartStrategy() {
			return new ThrowingRestartStrategy();
		}
	}
}

==> flink-runtime_2.11-1.12.1-sources.jar: org/apache/flink/runtime/executiongraph/restart/ThrowingRestartStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flink.runtime.executiongraph.restart;

import org.apache.flink.runtime.concurrent.ScheduledExecutor;

import java.util.concurrent.CompletableFuture;

/**
 * A restart strategy that validates that it is not in use by throwing {@link IllegalStateException}
 * on any method call.
 */
public class ThrowingRestartStrategy implements RestartStrategy {

    @Override
    public boolean canRestart() {
        throw new IllegalStateException("Unexpected canRestart() call");
    }

    @Override
    public CompletableFuture<Void> restart(
            final RestartCallback restarter, final ScheduledExecutor executor) {
        throw new IllegalStateException("Unexpected restart() call");
    }

    /** Factory for {@link ThrowingRestartStrategy}. */
    public static class ThrowingRestartStrategyFactory extends RestartStrategyFactory {

        private static final long serialVersionUID = 1L;

        @Override
        public RestartStrategy createRestartStrategy() {
            return new ThrowingRestartStrategy();
        }
    }
}
